# Woclema - Weblog, Originally Command Line Editable/Manageable
# Copyright (C) 2006-2007 Tommi Saviranta  <wnd@iki.fi>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


package Woclema::Config;

use strict;
use warnings FATAL => 'all';
use diagnostics;


# Basic settings
################################################################################


# Rewrite.
#   0: don't use rewriting
#   1: use "entry-N"
#   2: use "$baseurl/entry/N"
#
use vars qw($rewrite);
$rewrite = 1;		# Use mod_rewrite

my $db_host = "db";		# Database hostaddress
my $db_port;			# Database port (optional)
my $db_db = "weblog";		# Database name
my $db_user;			# Database user (optional)
my $db_pass;			# Database password (optional)

use vars qw($base_url);		# Required for Atom-feed
$base_url = "http://wnd.katei.fi/woclema-alien/";	# Weblog baseurl

# How many latest entries to show on default page.
use vars qw($latest_count);
$latest_count = 5;

# How many previous months with entries to show under calendar.
use vars qw($old_months);
$old_months = 12;


# Entry list settings
################################################################################


# If list of latest entries has exactly one entry, automatically
# show it with comments.
use vars qw($verbose_single_latest);
$verbose_single_latest = 0;

# If list of entries for given day has less than N entries, show the entries
# verbosely, but without comments. Otherwise print title only.
use vars qw($verbose_limit_day);
$verbose_limit_day = 5;

# If list of entries for given day has exactly one entry, automatically
# show it with comments.
use vars qw($verbose_single_day);
$verbose_single_day = 1;

# If list of entries for given month has less than N entries, show the entries
# verbosely, but without comments. Otherwise print title only.
use vars qw($verbose_limit_month);
$verbose_limit_month = 5;

# If list of entries for given month has exactly one entry, automatically
# show it with comments.
use vars qw($verbose_single_month);
$verbose_single_month = 1;

# If list of entries for given category has less than N entries, show the
# entries verbosely, but without comments. Otherwise print title only.
use vars qw($verbose_limit_category);
$verbose_limit_category = 0;

# If list of entries for given category has exactly one entry, automatically
# show it with comments.
use vars qw($verbose_single_category);
$verbose_single_category = 0;


# Feed settings
################################################################################


# Feed title
use vars qw($feed_title);
$feed_title = "yet another weblog powered by Woclema";

# Feed author name, email. Optional, but email cannot exist without name.
# '@' in email address needs to be escaped (foo@bar => foo\@bar)
use vars qw($feed_author_name $feed_author_email);
#$feed_author_name = "Tommi Saviranta";
#$feed_author_email = "wnd+woclema\@iki.fi";

# Number of entries in feed file
use vars qw($feed_entries);
$feed_entries = 10;

# Number of words of entry content to include to the feed entry.
# Set 0 to disable, -1 to include everything.
# Note that this value may not be exact.
use vars qw($feed_content_length);
$feed_content_length = -1;



=item get_db
Get database connect info

r: (host, port, database, user, password) (stuff can be undef)
=cut
sub get_db() {
	return ($db_host, $db_port, $db_db, $db_user, $db_pass);
}



return 1;
