#! /usr/bin/perl
#
# Woclema - Weblog, Originally Command Line Editable/Manageable
# Copyright (C) 2006-2007 Tommi Saviranta  <wnd@iki.fi>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# wanha - your pesky URL-guardian for IRC


use strict;
use warnings FATAL => 'all';
use diagnostics;

use Woclema::Atom;
use Woclema::Entry;

use Woclema::Link;


=item strip
Strip HTML content into n words.

0: html
1: n
r: html
=cut
sub strip($$) {
	my ($txt, $n) = @_;
	($n == 0) && return undef;
	($n == -1) && return $txt;
	my $ret = "";
	my @tags;
my $debug = 0;

	my @split = split(/</, $txt);
	foreach my $chunk (@split) {
		my $t = $chunk;
		$t =~ s/\s//g;
		next if ($t eq "");
($debug == 1) && print "\n\n< $chunk >\n";
		my ($stag, $w) = split(/>/, $chunk, 2);
($debug == 1) && print "stag: $stag\n";
($debug == 1) && print "   w: $w\n";
		my $tag = $stag;
		if ($stag =~ /^\s*\//) {
			$tag =~ s/^.//;
			$tag =~ s/\s.*//;
($debug == 1) && print "-- closing tag $tag ($stag)\n";
($debug == 1) && print "  tags: " . ($#tags + 1) . "\n";
($debug == 1) && print "  latest: " . $tags[$#tags] . "\n";
			if ($#tags == -1 || $tags[$#tags] ne $tag) {
				return "bad html";
			}
			pop(@tags);
			$ret .= "<$stag>";
		} elsif ($stag =~ /\/\s*$/) {
			$ret .= "<$stag>";
		} elsif (! ($stag =~ /\/\s*$/)) {
			$tag =~ s/\s.*//;
			push(@tags, $tag);
			$ret .= "<$stag>";
($debug == 1) && print "-- opening tag $tag ($stag)\n";
		}

		$ret .= " " if ($#tags == -1 || $tags[$#tags] ne "a");
		my @words = split(/\s+/s, $w);
		for (my $i = 0; $i <= $#words && $n > 0; $i++) {
			($words[$i] eq "") && next;
			$ret .= $words[$i];
			$ret .= " " if ($#tags == -1 || $tags[$#tags] ne "a"
					|| $i < $#words);
($debug == 1) && print "w: -$words[$i]-\n";
			$n--;
		}
		last if ($n <= 0);
	}
	while ($#tags >= 0) {
		$ret .= "</" . pop(@tags) . ">";
	}

	if ($ret =~ /<\s*\//) {
		$ret .= "<p>...</p>";
	} else {
		$ret .= " ...";
	}

	return $ret;
}


=item main
Get Atom-feed of the weblog.
=cut
sub main() {
	my $latest = time();
	my $n = $Woclema::Config::feed_entries;

	my @list = &Woclema::Entry::get_list_before_time($latest, $n);
	my @e_list;
	foreach (@list) {
		my %orig = %{$_};
		my %e = (
			"id"		=> &Woclema::Atom::id(
						Woclema::Atom::ENTRY,
						$orig{'id'}),
			"title" 	=> $orig{'title'},
			"content"	=> $orig{'text'},
			"link"		=> &Woclema::Link::entry($orig{'id'}),
			"published"	=> $orig{'time_epoch'},
			"updated"	=> $orig{'edit_epoch'}
			);
		if ($Woclema::Config::feed_content_length != 0) {
			my $txt = &strip($orig{'text'},
					$Woclema::Config::feed_content_length);
			$e{"content"} = $txt;

			# Guess content type
			if ($txt =~ /<\//s) {
				$e{'content-type'} = "html";
			} else {
				$e{'content-type'} = "text";
			}
		}
		push(@e_list, \%e);
	}

	print <<EOF;
Content-Type: application/atom+xml; charset=utf-8

EOF
	my @now = gmtime();
	print &Woclema::Atom::sprint(\@now, @e_list);
}


&main();
